SharedBPlusTree

Struct SharedBPlusTree 

pub struct SharedBPlusTree<P, KC, IC>
where P: Pager + Clone, P::Page: Send + Sync + 'static, P::Id: Send + Sync + 'static, KC: KeyCodec, IC: IdCodec<Id = P::Id>,
{ /* private fields */ }
A façade that provides a serialized writer and snapshot readers, while implementing the same BTree trait.

Implementations

Source

impl<P, KC, IC> SharedBPlusTree<P, KC, IC>
where P: Pager + Clone, P::Page: Send + Sync + 'static, P::Id: Send + Sync + 'static, KC: KeyCodec, IC: IdCodec<Id = P::Id>,

pub fn create_empty( pager: P, opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>, ) -> Result<Self, Error>

Create an empty tree + shared writer.

pub fn open( pager: P, root: P::Id, opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>, ) -> Self

Open a shared B+Tree backed by an existing root.

pub fn snapshot(&self) -> BPlusTree<P, KC, IC>

Produce a snapshot tree at the current published root. This is a normal BPlusTree you can iterate with ScanOpts.

pub fn start_stream_with_opts( &self, opts: ScanOpts<'static, KC>, ) -> Receiver<(KC::Key, Vec<u8>)>
where P: Send + 'static, P::Id: Send + 'static, KC: KeyCodec + 'static, KC::Key: Send + Sync + 'static, IC: IdCodec<Id = P::Id> + 'static,

Start a streaming scan at the current root, using any ScanOpts. Returns a crossbeam MPMC receiver; read it from as many threads as you like. Keys/values are owned (no borrows across threads).