pub struct SharedBPlusTree<P, KC, IC>where
P: Pager + Clone,
P::Page: Send + Sync + 'static,
P::Id: Send + Sync + 'static,
KC: KeyCodec,
IC: IdCodec<Id = P::Id>,{ /* private fields */ }Expand description
A façade that provides a serialized writer and snapshot readers,
while implementing the same BTree trait.
Implementations
Sourcepub fn create_empty(
pager: P,
opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>,
) -> Result<Self, Error>
pub fn create_empty( pager: P, opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>, ) -> Result<Self, Error>
Create an empty tree + shared writer.
Sourcepub fn open(
pager: P,
root: P::Id,
opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>,
) -> Self
pub fn open( pager: P, root: P::Id, opt_shared_node_cache: Option<Arc<RwLock<NodeCache<P>>>>, ) -> Self
Open a shared B+Tree backed by an existing root.
Sourcepub fn snapshot(&self) -> BPlusTree<P, KC, IC>
pub fn snapshot(&self) -> BPlusTree<P, KC, IC>
Produce a snapshot tree at the current published root.
This is a normal BPlusTree you can iterate with ScanOpts.